@@ -1,5 +1,6 @@
 #include "QvkMagnifier.h"
 
+
 using namespace std;
 
 
@@ -36,74 +37,34 @@ void QvkMagnifier::closeEvent( QCloseEvent * event )
 
 void QvkMagnifier::getDialogMagnifier( QWidget *parent )
 {
-  dialog = new QDialog( parent );
+  (void)parent;
+  
+  newDialog = new QDialog;
+  newDialog->setModal( true );
 
-  QFont qfont = dialog->font();
-  qfont.setPixelSize( 12 );
-  dialog->setFont( qfont );
+  Ui_Dialog myUiDialog;
+  myUiDialog.setupUi( newDialog );
+  newDialog->show();  
 
-  QLabel* label = new QLabel( dialog );
-  label->setText("");
-  label->setGeometry( QRect( 20, 30, 120, 150) );
-  label->setAlignment( Qt::AlignCenter );
-  label->show();
-  QImage* qImage = new QImage( ":/pictures/magnifier.png" );
-  label->setPixmap( QPixmap::fromImage( *qImage, Qt::AutoColor ) );
-  label->setScaledContents( true );
-
-  radioButton1 = new QRadioButton( dialog );
-  radioButton1->setGeometry( 170, 50, 200, 21 );
-  radioButton1->setText( "200 x 200" );
-  radioButton1->show();
-  connect( radioButton1, SIGNAL( clicked() ), SLOT( Magnifier200x200() ) );
+  connect( myUiDialog.radioButton1, SIGNAL( clicked() ), SLOT( Magnifier200x200() ) );
   if ( formValue == 1 )
-    radioButton1->setChecked( true );
-
-  radioButton2 = new QRadioButton( dialog );
-  radioButton2->setGeometry( 170, 80, 200, 21 );
-  radioButton2->setText( "400 x 200" );
-  radioButton2->show();
-  connect( radioButton2, SIGNAL( clicked() ), SLOT( Magnifier400x200() ) );
+    myUiDialog.radioButton1->setChecked( true );
+  
+  connect( myUiDialog.radioButton2, SIGNAL( clicked() ), SLOT( Magnifier400x200() ) );
   if ( formValue == 2 )
-    radioButton2->setChecked( true );
-
-  radioButton3 = new QRadioButton( dialog );
-  radioButton3->setGeometry( 170, 110, 200, 21 );
-  radioButton3->setText( "600 x 200" );
-  radioButton3->show();
-  connect( radioButton3, SIGNAL( clicked() ), SLOT( Magnifier600x200() ) );
+    myUiDialog.radioButton2->setChecked( true );
+  
+  connect( myUiDialog.radioButton3, SIGNAL( clicked() ), SLOT( Magnifier600x200() ) );
   if ( formValue == 3 )
-    radioButton3->setChecked( true );
-    
-  QPushButton *button = new QPushButton( dialog );
-  button->setGeometry( QRect( 220, 170, 65, 25 ) );
-  button->setText( "Close" );
-  connect( button, SIGNAL( clicked() ), SLOT( closeDialog() ) );
+    myUiDialog.radioButton3->setChecked( true );
   
-  QPropertyAnimation *animation = new QPropertyAnimation( dialog, "geometry");
-  animation->setDuration( 1000 );
-  animation->setStartValue( QRect( parent->x() + parent->width()/2,
-                                   parent->y() + parent->height()/2,
-                                   0,
-                                   0 ) );
-
-  animation->setEndValue( QRect( ( parent->x() ) + ( ( parent->width()/2 ) - ( 300/2 ) ), 
-                                 ( parent->y() ) + ( ( parent->height()/2) - ( 200/2 ) ),
-                                   300,
-                                   200 ) );
-
-  animation->setEasingCurve( QEasingCurve::OutBounce );
-  animation->start();  
-  
-  //dialog->setFixedSize( 300, 200 );
-
-  dialog->exec();
+  connect( myUiDialog.buttonBox, SIGNAL( accepted() ), SLOT( closeDialog() ) );
 }
 
 
 void QvkMagnifier::closeDialog()
 {
-  dialog->close();
+  newDialog->close();
 }
 
 
