@@ -1,6 +1,29 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.0">
 <context>
-    <name>QvkMail</name>
+    <name>AlsaBusyDialog</name>
+    <message>
+        <source>Device is busy</source>
+        <translation>الجهاز مشغول حاليا</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>الاسم</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>مجهول</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>الجهاز</translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation>مستخدمة من طرف</translation>
+    </message>
+</context>
+<context>
+    <name>MailDialog</name>
     <message>
         <source>Mail last Video</source>
         <translation>أرسل آخر فيديو</translation>
@@ -13,6 +36,13 @@
         <source>Send</source>
         <translation>أرسل</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>ألغِ</translation>
+    </message>
+</context>
+<context>
+    <name>QvkMail</name>
     <message>
         <source>You find the Video as attachment</source>
         <translation>سوف تجد الفيديو على شكل رابط</translation>
@@ -23,11 +53,7 @@
     </message>
 </context>
 <context>
-    <name>QvkWebcam</name>
-    <message>
-        <source>Noborder</source>
-        <translation>بدون حاشية</translation>
-    </message>
+    <name>QvkWebcamWindow</name>
     <message>
         <source>Border</source>
         <translation>حاشية</translation>
@@ -36,20 +62,32 @@
         <source>Close</source>
         <translation>أغلق</translation>
     </message>
+    <message>
+        <source>Show over fullscreen</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
-    <name>QvkWebcamController</name>
-    <message>
-        <source>Webcam</source>
-        <translation>كاميرا الوب</translation>
-    </message>
+    <name>WebcamBusyDialog</name>
     <message>
         <source>Device is busy</source>
         <translation>الجهاز مشغول حاليا</translation>
     </message>
     <message>
-        <source>Select webcam</source>
-        <translation>اِختر كاميرا</translation>
+        <source>Name</source>
+        <translation>الاسم</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>الجهاز</translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation>مستخدمة من طرف</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>مجهول</translation>
     </message>
 </context>
 <context>
@@ -150,10 +188,6 @@
         <source>Open Directory</source>
         <translation>افتح الدليل</translation>
     </message>
-    <message>
-        <source>%1</source>
-        <translation>%1</translation>
-    </message>
     <message>
         <source>Countdown</source>
         <translation>عدّ تنازلي</translation>
@@ -174,10 +208,6 @@
         <source>Actual frames per second</source>
         <translation>عدد المشاهد \ ثا الحالية</translation>
     </message>
-    <message>
-        <source>Device %1 is busy</source>
-        <translation>الجهاز %1 مشغول حالياً</translation>
-    </message>
     <message>
         <source>Go</source>
         <translation>واصِل</translation>
@@ -206,10 +236,6 @@
         <source>Beta openSUSE</source>
         <translation>نسخة تجريبية openSUSE</translation>
     </message>
-    <message>
-        <source>Beta Ubuntu</source>
-        <translation>نسخة تجريبية Ubuntu</translation>
-    </message>
     <message>
         <source>Donate</source>
         <translation>تبرع</translation>
@@ -242,5 +268,25 @@
         <source>Audiocodec</source>
         <translation>ترميز الصوت</translation>
     </message>
+    <message>
+        <source>Webcam</source>
+        <translation>كاميرا الوب</translation>
+    </message>
+    <message>
+        <source>Select webcam</source>
+        <translation>اِختر كاميرا</translation>
+    </message>
+    <message>
+        <source>Mirrored</source>
+        <translation>معكوس</translation>
+    </message>
+    <message>
+        <source>Display</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>All Displays</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
