@@ -1,6 +1,29 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.0">
 <context>
-    <name>QvkMail</name>
+    <name>AlsaBusyDialog</name>
+    <message>
+        <source>Device is busy</source>
+        <translation>El preséu ta ocupáu</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Desconocíu</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>Preséu</translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation>Usáu por</translation>
+    </message>
+</context>
+<context>
+    <name>MailDialog</name>
     <message>
         <source>Mail last Video</source>
         <translation>Dunviar per corréu&apos;l vidéu caberu</translation>
@@ -13,6 +36,13 @@
         <source>Send</source>
         <translation>Dunviar</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Encaboxar</translation>
+    </message>
+</context>
+<context>
+    <name>QvkMail</name>
     <message>
         <source>You find the Video as attachment</source>
         <translation>Pues alcontrar el vidéu como axuntu</translation>
@@ -23,33 +53,41 @@
     </message>
 </context>
 <context>
-    <name>QvkWebcam</name>
-    <message>
-        <source>Noborder</source>
-        <translation>Ensin bordes</translation>
-    </message>
+    <name>QvkWebcamWindow</name>
     <message>
         <source>Border</source>
-        <translation>Borde</translation>
+        <translation>Bervesu</translation>
     </message>
     <message>
         <source>Close</source>
         <translation>Zarrar</translation>
     </message>
+    <message>
+        <source>Show over fullscreen</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
-    <name>QvkWebcamController</name>
-    <message>
-        <source>Webcam</source>
-        <translation>Cámara web</translation>
-    </message>
+    <name>WebcamBusyDialog</name>
     <message>
         <source>Device is busy</source>
         <translation>El preséu ta ocupáu</translation>
     </message>
     <message>
-        <source>Select webcam</source>
-        <translation>Esbillar cámara web</translation>
+        <source>Name</source>
+        <translation>Nome</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>Preséu</translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation>Usáu por</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Desconocíu</translation>
     </message>
 </context>
 <context>
@@ -60,7 +98,7 @@
     </message>
     <message>
         <source>Window</source>
-        <translation>Ventanu</translation>
+        <translation>Ventana</translation>
     </message>
     <message>
         <source>Area</source>
@@ -84,7 +122,7 @@
     </message>
     <message>
         <source>Default</source>
-        <translation>Per defeutu</translation>
+        <translation>Por defeutu</translation>
     </message>
     <message>
         <source>Codec</source>
@@ -96,7 +134,7 @@
     </message>
     <message>
         <source>Videopath</source>
-        <translation>Ruta&apos;l vidéu</translation>
+        <translation>Camín del vidéu</translation>
     </message>
     <message>
         <source>Player</source>
@@ -148,11 +186,7 @@
     </message>
     <message>
         <source>Open Directory</source>
-        <translation>Abrir carpeta</translation>
-    </message>
-    <message>
-        <source>%1</source>
-        <translation>%1</translation>
+        <translation>Abrir direutoriu</translation>
     </message>
     <message>
         <source>Countdown</source>
@@ -168,16 +202,12 @@
     </message>
     <message>
         <source>Select one or more devices</source>
-        <translation>Esbilla un o más preseos</translation>
+        <translation>Esbilla ún o más preseos</translation>
     </message>
     <message>
         <source>Actual frames per second</source>
         <translation>Cuadros per segundu d&apos;anguaño</translation>
     </message>
-    <message>
-        <source>Device %1 is busy</source>
-        <translation>El preséu %1 ta ocupáu</translation>
-    </message>
     <message>
         <source>Go</source>
         <translation>DIr</translation>
@@ -206,10 +236,6 @@
         <source>Beta openSUSE</source>
         <translation>Beta openSUSE</translation>
     </message>
-    <message>
-        <source>Beta Ubuntu</source>
-        <translation>Beta Ubuntu</translation>
-    </message>
     <message>
         <source>Donate</source>
         <translation>Donar</translation>
@@ -232,7 +258,7 @@
     </message>
     <message>
         <source>New version available</source>
-        <translation>Nueva versión disponible</translation>
+        <translation>Versión nueva disponible</translation>
     </message>
     <message>
         <source>Videocodec</source>
@@ -242,5 +268,25 @@
         <source>Audiocodec</source>
         <translation>Codec soníu</translation>
     </message>
+    <message>
+        <source>Webcam</source>
+        <translation>Cámara web</translation>
+    </message>
+    <message>
+        <source>Select webcam</source>
+        <translation>Esbillar cámara web</translation>
+    </message>
+    <message>
+        <source>Mirrored</source>
+        <translation>Espeyáu</translation>
+    </message>
+    <message>
+        <source>Display</source>
+        <translation>Pantalla</translation>
+    </message>
+    <message>
+        <source>All Displays</source>
+        <translation>Toles pantalles</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
