@@ -1,6 +1,29 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.0">
 <context>
-    <name>QvkMail</name>
+    <name>AlsaBusyDialog</name>
+    <message>
+        <source>Device is busy</source>
+        <translation>Az eszköz foglalt</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Név</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Ismeretlen</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>Eszköz</translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation>Használta:</translation>
+    </message>
+</context>
+<context>
+    <name>MailDialog</name>
     <message>
         <source>Mail last Video</source>
         <translation>Utolsó videó levélként</translation>
@@ -13,6 +36,13 @@
         <source>Send</source>
         <translation>Küldés</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Mégse</translation>
+    </message>
+</context>
+<context>
+    <name>QvkMail</name>
     <message>
         <source>You find the Video as attachment</source>
         <translation>A videó csatolva</translation>
@@ -23,11 +53,7 @@
     </message>
 </context>
 <context>
-    <name>QvkWebcam</name>
-    <message>
-        <source>Noborder</source>
-        <translation>Keret nélkül</translation>
-    </message>
+    <name>QvkWebcamWindow</name>
     <message>
         <source>Border</source>
         <translation>Kerettel</translation>
@@ -36,20 +62,32 @@
         <source>Close</source>
         <translation>Bezár</translation>
     </message>
+    <message>
+        <source>Show over fullscreen</source>
+        <translation>Teljes képernyő</translation>
+    </message>
 </context>
 <context>
-    <name>QvkWebcamController</name>
-    <message>
-        <source>Webcam</source>
-        <translation>Webkamera</translation>
-    </message>
+    <name>WebcamBusyDialog</name>
     <message>
         <source>Device is busy</source>
         <translation>Az eszköz foglalt</translation>
     </message>
     <message>
-        <source>Select webcam</source>
-        <translation>Válasszon webkamerát</translation>
+        <source>Name</source>
+        <translation>Név</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>Eszköz</translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation>Használta:</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Ismeretlen</translation>
     </message>
 </context>
 <context>
@@ -150,10 +188,6 @@
         <source>Open Directory</source>
         <translation>Könyvtár megnyitása</translation>
     </message>
-    <message>
-        <source>%1</source>
-        <translation>%1</translation>
-    </message>
     <message>
         <source>Countdown</source>
         <translation>Visszaszámlálás</translation>
@@ -174,14 +208,6 @@
         <source>Actual frames per second</source>
         <translation>Képkockák száma másodpercenként</translation>
     </message>
-    <message>
-        <source>Device %1 is busy</source>
-        <translation>%1 eszköz foglalt</translation>
-    </message>
-    <message>
-        <source>Your Actual frames in the Settings is too heigh</source>
-        <translation>A beállított képkockaszám túl magas</translation>
-    </message>
     <message>
         <source>Go</source>
         <translation>Indít</translation>
@@ -210,10 +236,6 @@
         <source>Beta openSUSE</source>
         <translation>Beta openSUSE</translation>
     </message>
-    <message>
-        <source>Beta Ubuntu</source>
-        <translation>Beta Ubuntu</translation>
-    </message>
     <message>
         <source>Donate</source>
         <translation>Adományozás</translation>
@@ -238,5 +260,33 @@
         <source>New version available</source>
         <translation>Új verzió érhető el</translation>
     </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videokodek</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiokodek</translation>
+    </message>
+    <message>
+        <source>Webcam</source>
+        <translation>Webkamera</translation>
+    </message>
+    <message>
+        <source>Select webcam</source>
+        <translation>Válasszon webkamerát</translation>
+    </message>
+    <message>
+        <source>Mirrored</source>
+        <translation>Tükrözött</translation>
+    </message>
+    <message>
+        <source>Display</source>
+        <translation>Képernyő</translation>
+    </message>
+    <message>
+        <source>All Displays</source>
+        <translation>Összes képernyő</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
