@@ -1,6 +1,29 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
 <context>
-    <name>QvkMail</name>
+    <name>AlsaBusyDialog</name>
+    <message>
+        <source>Device is busy</source>
+        <translation>Urządzenie zajęte</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>MailDialog</name>
     <message>
         <source>Mail last Video</source>
         <translation>Wyślij ostatnie nagranie</translation>
@@ -13,6 +36,13 @@
         <source>Send</source>
         <translation>Wyślij</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>QvkMail</name>
     <message>
         <source>You find the Video as attachment</source>
         <translation>Nagranie wideo znajduje się w załączniku</translation>
@@ -23,11 +53,7 @@
     </message>
 </context>
 <context>
-    <name>QvkWebcam</name>
-    <message>
-        <source>Noborder</source>
-        <translation>Bez ramki</translation>
-    </message>
+    <name>QvkWebcamWindow</name>
     <message>
         <source>Border</source>
         <translation>Ramka</translation>
@@ -36,20 +62,32 @@
         <source>Close</source>
         <translation>Zamknij</translation>
     </message>
+    <message>
+        <source>Show over fullscreen</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
-    <name>QvkWebcamController</name>
-    <message>
-        <source>Webcam</source>
-        <translation>Kamera</translation>
-    </message>
+    <name>WebcamBusyDialog</name>
     <message>
         <source>Device is busy</source>
         <translation>Urządzenie zajęte</translation>
     </message>
     <message>
-        <source>Select webcam</source>
-        <translation>Wybierz kamerę</translation>
+        <source>Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -150,10 +188,6 @@
         <source>Open Directory</source>
         <translation>Wybierz katalog</translation>
     </message>
-    <message>
-        <source>%1</source>
-        <translation>%1</translation>
-    </message>
     <message>
         <source>Countdown</source>
         <translation>Odliczanie</translation>
@@ -174,10 +208,6 @@
         <source>Actual frames per second</source>
         <translation>Aktualna liczba klatek na sekundę</translation>
     </message>
-    <message>
-        <source>Device %1 is busy</source>
-        <translation>Urządzenie %1 jest zajęte</translation>
-    </message>
     <message>
         <source>Go</source>
         <translation>Wznów</translation>
@@ -206,10 +236,6 @@
         <source>Beta openSUSE</source>
         <translation>Beta openSUSE</translation>
     </message>
-    <message>
-        <source>Beta Ubuntu</source>
-        <translation>Beta Ubuntu</translation>
-    </message>
     <message>
         <source>Donate</source>
         <translation>Darowizna</translation>
@@ -242,5 +268,25 @@
         <source>Audiocodec</source>
         <translation>Kodek audio</translation>
     </message>
+    <message>
+        <source>Webcam</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Select webcam</source>
+        <translation>Wybierz kamerę</translation>
+    </message>
+    <message>
+        <source>Mirrored</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Display</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>All Displays</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
