@@ -2,7 +2,30 @@
 <!DOCTYPE TS>
 <TS version="2.0">
 <context>
-    <name>QvkMail</name>
+    <name>AlsaBusyDialog</name>
+    <message>
+        <source>Device is busy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>MailDialog</name>
     <message>
         <source>Mail last Video</source>
         <translation type="unfinished"></translation>
@@ -15,6 +38,13 @@
         <source>Send</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QvkMail</name>
     <message>
         <source>You find the Video as attachment</source>
         <translation type="unfinished"></translation>
@@ -25,11 +55,7 @@
     </message>
 </context>
 <context>
-    <name>QvkWebcam</name>
-    <message>
-        <source>Noborder</source>
-        <translation type="unfinished"></translation>
-    </message>
+    <name>QvkWebcamWindow</name>
     <message>
         <source>Border</source>
         <translation type="unfinished"></translation>
@@ -38,19 +64,31 @@
         <source>Close</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>QvkWebcamController</name>
     <message>
-        <source>Webcam</source>
+        <source>Show over fullscreen</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>WebcamBusyDialog</name>
     <message>
         <source>Device is busy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Select webcam</source>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Used by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -152,10 +190,6 @@
         <source>Open Directory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>%1</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Countdown</source>
         <translation type="unfinished"></translation>
@@ -176,10 +210,6 @@
         <source>Actual frames per second</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Device %1 is busy</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Go</source>
         <translation type="unfinished"></translation>
@@ -204,14 +234,6 @@
         <source>Frames</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Beta openSUSE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Beta Ubuntu</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Donate</source>
         <translation type="unfinished"></translation>
@@ -244,5 +266,29 @@
         <source>Audiocodec</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Webcam</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select webcam</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mirrored</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Displays</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Developer Homepage</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
