@@ -1,5 +1,5 @@
 /* vokoscreen - A desktop recorder
- * Copyright (C) 2011-2013 Volker Kohaupt
+ * Copyright (C) 2011-2014 Volker Kohaupt
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,7 +12,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301 USA 
  */
 
 #include "regionselection.h" 
@@ -89,33 +90,6 @@ void regionselection::saveSettings()
   settings.endGroup();
 }
 
-
-void regionselection::cleanRecordArea( bool state )
-{
-  if ( state )
-  {
-    QRegion regionWidget(  0, 
-                           0, 
-                           width(),
-                           height(), 
-                           QRegion::Rectangle );
-  
-    QRegion regionRecord( borderLeft + frameWidth / 2, 
-                          borderTop + frameWidth / 2, 
-                          width() - borderLeft - borderRight - frameWidth,
-                          height() - borderTop - borderBottom - frameWidth, 
-                          QRegion::Rectangle );
-    
-    QRegion region = regionWidget.subtract( regionRecord );
-    setMask( region );
-  }
-  else
-  {
-    clearMask();
-  }
-}
-
-
 void regionselection::HandleTopLeft()
 {
   QColor color, arrow;
@@ -568,9 +542,8 @@ void regionselection::paintEvent( QPaintEvent *event )
   {
     printSize();
     HandleMiddle();
-    
-    // Widget
     clearMask();
+    
     QRegion RegionWidget( 0, 0, width(), height() );
     
     // RecordArea
@@ -584,13 +557,29 @@ void regionselection::paintEvent( QPaintEvent *event )
 
     // Retrieves and merge display-area-size in record Area
     QRegion r1 = RegionNew.united( getPrintSizeRectForMask() );
+    
     // HandleMiddle
     // Retrieves and merge HandleMiddle in record Area
     r1 = r1.united( getHandleMiddleForMask() );
-    
     setMask( r1 );
   }
+  else
+  {
+    // Widget
+    clearMask();
+    QRegion RegionWidget( 0, 0, width(), height() );
+    
+    // RecordArea
+    QRegion RegionArea  ( borderLeft + frameWidth / 2,
+                          borderTop + frameWidth / 2,
+                          width() - ( borderLeft + frameWidth / 2 ) - ( borderRight + frameWidth / 2 ),
+                          height() - ( borderTop + frameWidth / 2 ) - ( borderBottom + frameWidth / 2 ) );
 
+    // subtract the record Area
+    QRegion RegionNew = RegionWidget.subtract( RegionArea );
+
+    setMask( RegionNew );
+  }
 
   HandleTopLeft();
   HandleTopMiddle();
@@ -600,8 +589,6 @@ void regionselection::paintEvent( QPaintEvent *event )
   HandleBottomMiddle();
   HandleBottomLeft();
   HandleLeftMiddle();
-  //HandleMiddle();
-  //printSize();
 
   // Blue Frame
   painter->setPen( QPen( Qt::blue, frameWidth ) );
@@ -643,6 +630,7 @@ bool regionselection::isFrameLocked()
 void regionselection::handlingFrameLock()
 {
   repaint();
+  update();
 }
 
 
