@@ -12,8 +12,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301 USA 
  */
+
 #include "screencast.h"  
 
 using namespace std;
@@ -43,8 +45,9 @@ screencast::screencast()
     qDebug() << "[vokoscreen]" << "Qt Version: " << qVersion();
     QvkAlsaDevice inBox ;
     qDebug() << "[vokoscreen]" << "asoundlib Version:" << inBox.getAlsaVersion();
+    qDebug() << "[vokoscreen] current icon-theme:" << QIcon::themeName();
     qDebug();
-    
+
     searchExternalPrograms();
     
     pause = false;
@@ -86,19 +89,16 @@ screencast::screencast()
     
     MagnifierCheckBox = new QCheckBox( frame );
     MagnifierCheckBox->setText( tr( "Magnification" ) );
-    MagnifierCheckBox->setGeometry( QRect( 160, 15, 120, 21 ) );
+    MagnifierCheckBox->setGeometry( QRect( 160, 40, 120, 21 ) );
     MagnifierCheckBox->setToolTip( "CTRL+SHIFT+F9" );
     MagnifierCheckBox->show();
 
     QPushButton *MagnifierDialogPushButton = new QPushButton( frame );
-    MagnifierDialogPushButton->setGeometry( 270, 15, 20, 21 );
+    MagnifierDialogPushButton->setGeometry( 270, 40, 20, 21 );
     MagnifierDialogPushButton->setText( "..." );
     MagnifierDialogPushButton->show();
     connect( MagnifierDialogPushButton, SIGNAL( clicked() ), SLOT( MagnifierDialog() ) );
     
-    webcamCheckBox = new QvkWebcamController( frame );
-    webcamCheckBox->setGeometry( 160, 40, 120, 21 );
-
     QLabel *CountdownLabel = new QLabel( frame );
     CountdownLabel->setGeometry( 160, 110, 80, 25 );
     CountdownLabel->setText( tr( "Countdown" ) );
@@ -112,26 +112,25 @@ screencast::screencast()
     CountdownSpinBox->setValue( 0 );
     CountdownSpinBox->show();
     
-    
-    // http://doc-snapshot.qt-project.org/4.8/qdesktopwidget.html#availableGeometry
-    QComboBox *ScreenComboBox = new QComboBox( frame );
-    ScreenComboBox->setGeometry( 160, 65, 200, 21 );
-    ScreenComboBox->hide();
+    ScreenComboBox = new QComboBox( frame );
+    ScreenComboBox->setGeometry( 160, 15, 200, 21 );
+    //ScreenComboBox->hide();
     QDesktopWidget *desk = QApplication::desktop();
     qDebug() << "[vokoscreen]" << "---Begin search Screen---";
     qDebug() << "[vokoscreen]" << "Number of screens:" << desk->screenCount();
     for ( int i = 0; i < desk->screenCount(); i++ )
     {
+      QString ScreenGeometryX1 = QString::number( desk->screenGeometry( i + 1 ).left() );
+      QString ScreenGeometryY1 = QString::number( desk->screenGeometry( i + 1 ).top() );      
       QString ScreenGeometryX = QString::number( desk->screenGeometry( i + 1 ).width() );
-      QString ScreenGeometryY = QString::number( desk->screenGeometry( i + 1 ).height() );      
-      ScreenComboBox->addItem( "Display " + QString::number( i ) + "   " + ScreenGeometryX + " x " + ScreenGeometryY, i );      
-      qDebug() << "[vokoscreen]" << "Display " + QString::number( i ) + "   " + ScreenGeometryX + " x " + ScreenGeometryY ;
+      QString ScreenGeometryY = QString::number( desk->screenGeometry( i + 1 ).height() );
+      ScreenComboBox->addItem( tr( "Display" ) + " " + QString::number( i + 1 ) + ":  " + ScreenGeometryX + " x " + ScreenGeometryY, i );
+      qDebug() << "[vokoscreen]" << "Display " + QString::number( i + 1 ) + ":  " + ScreenGeometryX + " x " + ScreenGeometryY + "+" + ScreenGeometryX1 + "+" + ScreenGeometryY1;
     }
+    ScreenComboBox->addItem( tr( "All Displays" ), -1 );    
     qDebug() << "[vokoscreen]" << "---End search Screen---";
     qDebug();
     
-    
-    
     // Tab 2 Audio options ****************************************
     TabWidgetAudioFrame = new QFrame( this );
     TabWidgetAudioFrame->setGeometry( 120, 0, 300, 290 );
@@ -179,12 +178,11 @@ screencast::screencast()
 
     QLabel *VideoOptionLabel = new QLabel( TabWidgetVideoOptionFrame );
     VideoOptionLabel->setGeometry( 20, 10, 50, 25 );
-    //VideoOptionLabel->setAlignment( Qt::AlignRight );
     VideoOptionLabel->setText( tr( "Frames" ) );
     VideoOptionLabel->show();
 
     FrameSpinBox = new QSpinBox( TabWidgetVideoOptionFrame );
-    FrameSpinBox->setGeometry( QRect( 80, 10, 50, 25 ) );
+    FrameSpinBox->setGeometry( QRect( 100, 10, 50, 25 ) );
     FrameSpinBox->setMinimum( 1 );
     FrameSpinBox->setMaximum( 200 );
     FrameSpinBox->setSingleStep( 1 );
@@ -193,8 +191,10 @@ screencast::screencast()
     connect( FrameSpinBox, SIGNAL( valueChanged( int ) ), SLOT( valueChangedFrames( int ) ) );
 
     QPushButton *FrameStandardButton = new QPushButton( TabWidgetVideoOptionFrame );
-    FrameStandardButton->setText( tr( "Default" ) );
-    FrameStandardButton->setGeometry( 360, 10, 70, 25 );
+    FrameStandardButton->setIcon ( QIcon::fromTheme( "edit-undo", QIcon( ":/pictures/undo.png" ) ) );
+    FrameStandardButton->setText( "" );
+    FrameStandardButton->setGeometry( 350, 10, 50, 25 );
+    FrameStandardButton->setToolTip( tr( "Default" ) );
     FrameStandardButton->show();
     connect( FrameStandardButton, SIGNAL( clicked() ), SLOT( setFrameStandardSpinbox() ) );
 
@@ -223,8 +223,10 @@ screencast::screencast()
     connect( VideoContainerComboBox, SIGNAL( currentIndexChanged( int ) ), SLOT( currentIndexChangedFormat( int ) ) );
     
     QPushButton *VideocodecStandardButton = new QPushButton( TabWidgetVideoOptionFrame );
-    VideocodecStandardButton->setText( tr( "Default" ) );
-    VideocodecStandardButton->setGeometry( 360, 40, 70, 25 );
+    VideocodecStandardButton->setIcon ( QIcon::fromTheme( "edit-undo", QIcon( ":/pictures/undo.png" ) ) );
+    VideocodecStandardButton->setText( "" );
+    VideocodecStandardButton->setGeometry( 350, 40, 50, 25 );
+    VideocodecStandardButton->setToolTip( tr( "Default" ) );
     VideocodecStandardButton->show();
     connect( VideocodecStandardButton, SIGNAL( clicked() ), SLOT( setVideocodecStandardComboBox() ) );
     
@@ -240,12 +242,13 @@ screencast::screencast()
     AudiocodecComboBox->addItem( "libvorbis" );
     
     QPushButton *AudiocodecStandardButton = new QPushButton( TabWidgetVideoOptionFrame );
-    AudiocodecStandardButton->setText( tr( "Default" ) );
-    AudiocodecStandardButton->setGeometry( 360, 70, 70, 25 );
+    AudiocodecStandardButton->setIcon ( QIcon::fromTheme( "edit-undo", QIcon( ":/pictures/undo.png" ) ) );
+    AudiocodecStandardButton->setText( "" );
+    AudiocodecStandardButton->setGeometry( 350, 70, 50, 25 );
+    AudiocodecStandardButton->setToolTip( tr( "Default" ) );
     AudiocodecStandardButton->show();
     connect( AudiocodecStandardButton, SIGNAL( clicked() ), SLOT( setAudiocodecStandardComboBox() ) );
     
-    
     HideMouseCheckbox = new QCheckBox( TabWidgetVideoOptionFrame );
     HideMouseCheckbox->setGeometry( 20, 100, 300, 25 );
     HideMouseCheckbox->setText( tr( "Do not record mouse cursor" ) );
@@ -298,11 +301,82 @@ screencast::screencast()
     SystrayCheckBox->show();
     connect( SystrayCheckBox, SIGNAL( stateChanged( int ) ), SLOT( stateChangedSystray( int ) ) );
 
-    // Tab 5 About *********************************************************
+    // Tab 5 Webcam *******************************************************
+    TabWidgetWebcamFrame = new QFrame( this );
+    TabWidgetWebcamFrame->setGeometry( 120, 0, 300, 200 );
+    TabWidgetWebcamFrame->show();
+    tabWidget->addTab( TabWidgetWebcamFrame, "" );
+    tabWidget->setTabIcon( 4, QIcon::fromTheme( "camera-web", QIcon( ":/pictures/webcam.png" ) ) );
+    qfont = TabWidgetWebcamFrame->font();
+    qfont.setPixelSize( 12 );
+    TabWidgetWebcamFrame->setFont( qfont );
+
+    webcamCheckBox = new QCheckBox( TabWidgetWebcamFrame );
+    webcamCheckBox->setText( tr( "Webcam" ) );
+    webcamCheckBox->setToolTip( "CTRL+SHIFT+F8" );
+    webcamCheckBox->setGeometry( 20, 5, 120, 25 );
+    webcamCheckBox->show();
+  
+    QComboBox *webcamComboBox = new QComboBox( TabWidgetWebcamFrame );
+    webcamComboBox->setGeometry( 120, 5, 220, 25 );
+    webcamComboBox->setToolTip( tr ( "Select webcam" ) );
+    webcamComboBox->show();
+
+    mirrorCheckBox = new QCheckBox( TabWidgetWebcamFrame );
+    mirrorCheckBox->setText( tr( "Mirrored" ) );
+    mirrorCheckBox->setGeometry( 20, 70, 200, 25 );
+    mirrorCheckBox->show();
+
+    QFrame *dialFrame = new QFrame( TabWidgetWebcamFrame );
+    dialFrame->setFrameShape( QFrame::StyledPanel );
+    dialFrame->setFrameShadow( QFrame::Sunken );
+    dialFrame->setGeometry( 200, 40, 86, 86 );
+    dialFrame->show();
+  
+    int dialWith = 40;
+    int dialheight = 40;
+    rotateDial = new QDial( dialFrame );
+    rotateDial->setWrapping ( true );
+    rotateDial->setGeometry( dialFrame->width() / 2 - dialWith / 2, 
+			     dialFrame->height() / 2 - dialheight / 2, 
+			     dialWith,
+			     dialheight );
+
+    int radioButtonwidth = 20;
+    int radioButtonheight = 20;
+    radioButtonTopMiddle = new QRadioButton( dialFrame );
+    radioButtonTopMiddle->setGeometry( rotateDial->x() + rotateDial->width() / 2 - radioButtonwidth / 2,
+                                       rotateDial->y() - radioButtonwidth,
+				       radioButtonwidth,
+				       radioButtonheight );
+  
+    radioButtonRightMiddle = new QRadioButton( dialFrame );
+    radioButtonRightMiddle->setGeometry( rotateDial->x() + rotateDial->width(),
+                                         rotateDial->y() + rotateDial->height() / 2 - radioButtonheight / 2,
+                                         radioButtonwidth,
+				         radioButtonheight );
+   
+    radioButtonBottomMiddle = new QRadioButton( dialFrame );
+    radioButtonBottomMiddle->setGeometry( rotateDial->x() + rotateDial->width() / 2 - radioButtonwidth / 2,
+                                       rotateDial->y() + rotateDial->height(),
+                                       radioButtonwidth,
+	 			       radioButtonheight );
+ 
+    radioButtonLeftMiddle = new QRadioButton( dialFrame );
+    radioButtonLeftMiddle->setGeometry( rotateDial->x() - radioButtonwidth,
+                                        rotateDial->y() + rotateDial->height() / 2 - radioButtonheight / 2,
+                                        radioButtonwidth,
+				        radioButtonheight );
+
+    webcamController = new QvkWebcamController( webcamCheckBox, webcamComboBox, mirrorCheckBox, 
+						dialFrame, rotateDial, radioButtonTopMiddle, radioButtonRightMiddle, radioButtonBottomMiddle, radioButtonLeftMiddle );
+    (void)webcamController;
+    
+    // Tab 6 About *********************************************************
     QFrame *TabWidgetAboutFrame = new QFrame(this);
     TabWidgetAboutFrame->show();
     tabWidget->addTab( TabWidgetAboutFrame, "" );
-    tabWidget->setTabIcon( 4, QIcon::fromTheme( "dialog-information", QIcon( ":/pictures/about.png" ) ) );
+    tabWidget->setTabIcon( 5, QIcon::fromTheme( "dialog-information", QIcon( ":/pictures/about.png" ) ) );
     tabWidget->show();
     qfont = TabWidgetAboutFrame->font();
     qfont.setPixelSize( 12 );
@@ -312,20 +386,20 @@ screencast::screencast()
     int leftSide = 0;
     int rightSide = tabWidget->width() / 2;
     
+    QLabel* labelOpensuseBetaUrl = new QLabel( TabWidgetAboutFrame );
+    labelOpensuseBetaUrl->setText( "<a href='http://linuxecke.volkoh.de/vokoscreen/vokoscreen.html'>" + tr( "Developer Homepage" ) + "</a>" );
+    labelOpensuseBetaUrl->setGeometry( leftSide, 10, labelWidth, 22 );
+    labelOpensuseBetaUrl->setOpenExternalLinks( true );
+    labelOpensuseBetaUrl->setAlignment( Qt::AlignCenter );    
+    labelOpensuseBetaUrl->show();
+    
     QLabel* labelWebSite = new QLabel( TabWidgetAboutFrame );
-    labelWebSite->setGeometry( leftSide, 10, labelWidth, 22 );
+    labelWebSite->setGeometry( leftSide, 30, labelWidth, 22 );
     labelWebSite->setText( homepage );
     labelWebSite->setOpenExternalLinks( true );
     labelWebSite->setAlignment( Qt::AlignCenter );
     labelWebSite->show();
 
-    QLabel* labelMailinglisteMail = new QLabel( TabWidgetAboutFrame );
-    labelMailinglisteMail->setText( mailingliste );
-    labelMailinglisteMail->setGeometry( leftSide, 30, labelWidth, 22 );
-    labelMailinglisteMail->setOpenExternalLinks( true );
-    labelMailinglisteMail->setAlignment( Qt::AlignCenter );    
-    labelMailinglisteMail->show();
-
     QLabel* labelMail = new QLabel( TabWidgetAboutFrame );
     labelMail->setGeometry( leftSide, 50, labelWidth, 22 );
     labelMail->setText( email );
@@ -339,35 +413,28 @@ screencast::screencast()
     labelDeveLoperMail->setOpenExternalLinks( true );
     labelDeveLoperMail->setAlignment( Qt::AlignCenter );    
     labelDeveLoperMail->show();
-    
-    QLabel* labelLanguageUrl = new QLabel( TabWidgetAboutFrame );
-    labelLanguageUrl->setText( "<a href='https://www.transifex.com/projects/p/vokoscreen/'>" + tr( "Translations" ) + "</a>" );
-    labelLanguageUrl->setGeometry( rightSide, 10, labelWidth, 22 );
-    labelLanguageUrl->setOpenExternalLinks( true );
-    labelLanguageUrl->setAlignment( Qt::AlignCenter );    
-    labelLanguageUrl->show();
-    
+   
     QLabel* labelSourcecodeUrl = new QLabel( TabWidgetAboutFrame );
     labelSourcecodeUrl->setText( "<a href='https://github.com/vkohaupt/vokoscreen'>" + tr( "Sourcecode" ) + "</a>" );
-    labelSourcecodeUrl->setGeometry( rightSide, 30, labelWidth, 22 );
+    labelSourcecodeUrl->setGeometry( rightSide, 10, labelWidth, 22 );
     labelSourcecodeUrl->setOpenExternalLinks( true );
     labelSourcecodeUrl->setAlignment( Qt::AlignCenter );    
     labelSourcecodeUrl->show();
     
-    QLabel* labelOpensuseBetaUrl = new QLabel( TabWidgetAboutFrame );
-    labelOpensuseBetaUrl->setText( "<a href='http://linuxecke.volkoh.de/vokoscreen/vokoscreen.html'>" + tr( "Beta openSUSE" ) + "</a>" );
-    labelOpensuseBetaUrl->setGeometry( rightSide, 50, labelWidth, 22 );
-    labelOpensuseBetaUrl->setOpenExternalLinks( true );
-    labelOpensuseBetaUrl->setAlignment( Qt::AlignCenter );    
-    labelOpensuseBetaUrl->show();
+    QLabel* labelLanguageUrl = new QLabel( TabWidgetAboutFrame );
+    labelLanguageUrl->setText( "<a href='https://www.transifex.com/projects/p/vokoscreen/'>" + tr( "Translations" ) + "</a>" );
+    labelLanguageUrl->setGeometry( rightSide, 30, labelWidth, 22 );
+    labelLanguageUrl->setOpenExternalLinks( true );
+    labelLanguageUrl->setAlignment( Qt::AlignCenter );    
+    labelLanguageUrl->show();
+
+    QLabel* labelMailinglisteMail = new QLabel( TabWidgetAboutFrame );
+    labelMailinglisteMail->setText( mailingliste );
+    labelMailinglisteMail->setGeometry( rightSide, 50, labelWidth, 22 );
+    labelMailinglisteMail->setOpenExternalLinks( true );
+    labelMailinglisteMail->setAlignment( Qt::AlignCenter );    
+    labelMailinglisteMail->show();
 
-    QLabel* labelUbuntuBetaUrl = new QLabel( TabWidgetAboutFrame );
-    labelUbuntuBetaUrl->setText( "<a href='http://ppa.launchpad.net/vokoscreen-dev/vokoscreen-daily/ubuntu/pool/main/v/vokoscreen/'>" + tr( "Beta Ubuntu" ) + "</a>" );
-    labelUbuntuBetaUrl->setGeometry( rightSide, 70, labelWidth, 22 );
-    labelUbuntuBetaUrl->setOpenExternalLinks( true );
-    labelUbuntuBetaUrl->setAlignment( Qt::AlignCenter );    
-    labelUbuntuBetaUrl->show();
-    
     QLabel * labelDonateUrl = new QLabel( TabWidgetAboutFrame );
     labelDonateUrl->setText( "<a href='http://www.kohaupt-online.de/hp/spende.html'>" + tr( "Donate" ) + "</a>" );
     labelDonateUrl->setGeometry( 0, 100, tabWidget->width(), 22 );
@@ -383,7 +450,6 @@ screencast::screencast()
     creditsQPushButton->setIcon( creditsIcon );
     creditsQPushButton->show();
     connect( creditsQPushButton, SIGNAL( clicked() ), SLOT( showCredits() ) );
-    
 
     // End Tabs *************************************************************
 
@@ -394,7 +460,7 @@ screencast::screencast()
     qfont.setPixelSize( 14 );
     qfont.setBold( true );
     recordButton->setFont( qfont );
-    recordButton->setGeometry( 170, 200, 70, 30 );
+    recordButton->setGeometry( 120, 200, 90, 30 );
     recordButton->show();
     connect( recordButton, SIGNAL( clicked() ), SLOT( preRecord() ) );
 
@@ -405,7 +471,7 @@ screencast::screencast()
     qfont.setPixelSize( 14 );
     qfont.setBold( true );
     StopButton->setFont( qfont );
-    StopButton->setGeometry( 240, 200, 70, 30 );
+    StopButton->setGeometry( 210, 200, 90, 30 );
     StopButton->setEnabled( false );
     StopButton->show();  
     connect( StopButton, SIGNAL( clicked() ), SLOT( Stop() ) );
@@ -417,7 +483,7 @@ screencast::screencast()
     qfont.setPixelSize( 14 );
     qfont.setBold( true );
     PauseButton->setFont( qfont );
-    PauseButton->setGeometry( 310, 200, 70, 30 );
+    PauseButton->setGeometry( 300, 200, 90, 30 );
     PauseButton->setCheckable( true );
     PauseButton->setEnabled( false );
     if ( needProgram( "mkvmerge" ) )
@@ -433,12 +499,12 @@ screencast::screencast()
     qfont.setPixelSize( 14 );
     qfont.setBold( true );
     PlayButton->setFont( qfont );
-    PlayButton->setGeometry( 380, 200, 70, 30 );
+    PlayButton->setGeometry( 390, 200, 90, 30 );
     PlayButton->show();
     connect( PlayButton, SIGNAL( clicked() ), SLOT( play() ) );
 
     sendPushButton = new QPushButton( centralWidget );
-    sendPushButton->setGeometry( 450, 200, 70, 30 );
+    sendPushButton->setGeometry( 480, 200, 90, 30 );
     qfont = sendPushButton->font();
     qfont.setPixelSize( 14 );
     qfont.setBold( true );
@@ -454,8 +520,8 @@ screencast::screencast()
   #ifndef NO_NEW_VERSION_CHECK
     QTimer::singleShot( 15000, &version, SLOT( doDownload() ) );
     connect( &version, SIGNAL( versionDownloadFinish() ), SLOT( buttonVersion() ) );
-    updateButton = new QPushButton( centralWidget );
-    updateButton->setGeometry( 530, 190, 45, 45 );
+    updateButton = new QPushButton( frame );
+    updateButton->setGeometry( 395, 100, 45, 45 );
     updateButton->setIcon( QIcon( ":/pictures/system-software-update.png" ) );
     updateButton->setIconSize( QSize( 35, 35 ) );
     updateButton->setToolTip( tr( "New version available" ) );
@@ -465,7 +531,6 @@ screencast::screencast()
     
     QLabel* label = new QLabel( centralWidget );
     label->setText("");
-    //label->setGeometry( QRect( 0, 0, 123, 240) );
     label->setGeometry( QRect( 10, 0, 100, 190 ) );
     label->setAlignment( Qt::AlignCenter );
     label->show();
@@ -545,8 +610,6 @@ screencast::screencast()
     QStringList playerList = QStringList()  << "kaffeine"
                                             << "vlc"
                                             << "gnome-mplayer"
-                                            << "ffplay"
-					    << "avplay"
                                             << "totem"
                                             << "pia"
                                             << "xine"
@@ -684,13 +747,17 @@ screencast::screencast()
    SystemTrayIconBlue = new QSystemTrayIcon( QIcon::fromTheme( "media-skip-forward", QIcon ( ":/pictures/go.png" ) ) );
    SystemTrayIconBlue->setToolTip( tr( "Go" ) );
 
-      SystrayCheckBox->setCheckState( Qt::CheckState( vkSettings.getSystray() ) );
-      stateChangedSystray( Qt::CheckState( vkSettings.getSystray() ) );
+   SystrayCheckBox->setCheckState( Qt::CheckState( vkSettings.getSystray() ) );
+   stateChangedSystray( Qt::CheckState( vkSettings.getSystray() ) );
    
    connect( SystemTrayIconGreen,  SIGNAL( activated ( QSystemTrayIcon::ActivationReason ) ), this, SLOT( SystemTrayStart( QSystemTrayIcon::ActivationReason ) ) );
    connect( SystemTrayIconRed,    SIGNAL( activated ( QSystemTrayIcon::ActivationReason ) ), this, SLOT( SystemTrayStop( QSystemTrayIcon::ActivationReason ) ) );
    connect( SystemTrayIconYellow, SIGNAL( activated ( QSystemTrayIcon::ActivationReason ) ), this, SLOT( SystemTrayPause( QSystemTrayIcon::ActivationReason ) ) );
    connect( SystemTrayIconBlue,   SIGNAL( activated ( QSystemTrayIcon::ActivationReason ) ), this, SLOT( SystemTrayGo( QSystemTrayIcon::ActivationReason ) ) ); 
+
+   shortcutWebcam = new QxtGlobalShortcut( this );
+   connect( shortcutWebcam, SIGNAL( activated() ), this, SLOT( ShortcutWebcam() ) );
+   shortcutWebcam->setShortcut( QKeySequence( "Ctrl+Shift+F8" ) );
    
    shortcutMagnifier = new QxtGlobalShortcut( this );
    connect( shortcutMagnifier, SIGNAL( activated() ), this, SLOT( ShortcutMagnifier() ) );
@@ -727,6 +794,29 @@ screencast::~screencast()
 {
 }
 
+
+// Only for testing no funktion
+void screencast::styleChange( QStyle &oldStyle )
+{
+    qDebug() << "[vokoscreen] old styleSheet:" <<  &oldStyle; 
+}
+
+// Only for testing no funktion
+void screencast::changeEvent( QEvent *event )
+{
+  switch ( event->type() ) 
+  {
+    case QEvent::StyleChange:
+        qDebug() << "[vokoscreen] current icon-theme" << QIcon::themeName();
+        tabWidget->setTabIcon( 0, QIcon::fromTheme( "video-display", QIcon( ":/pictures/monitor.png" ) ) );      
+        tabWidget->setTabIcon( 1, QIcon::fromTheme( "audio-input-microphone", QIcon( ":/pictures/micro.png" ) ) );
+	break;
+    default:
+        break;
+    }
+}
+
+
 #ifndef NO_NEW_VERSION_CHECK
 void screencast::buttonVersion()
 {
@@ -977,8 +1067,7 @@ void screencast::closeEvent( QCloseEvent * event )
   saveSettings();
   myregionselection->close();
   magnifier->close();
-  if ( webcamCheckBox->isVisible()  )
-     webcamCheckBox->webcamClose();
+  webcamController->webcamCloseEvent();  
 }
 
 
@@ -1041,12 +1130,25 @@ void screencast::saveSettings()
     settings.setValue( "Width", myregionselection->getWidth() );
     settings.setValue( "Height", myregionselection->getHeight() );
   settings.endGroup();
-  
-  webcamCheckBox->saveSettings();
   myregionselection->saveSettings();
+
+  settings.beginGroup( "Webcam" );
+    settings.setValue( "Mirrored", mirrorCheckBox->checkState() );
+    settings.setValue( "Rotate", rotateDial->value() );
+    settings.setValue( "Top", radioButtonTopMiddle->isChecked() );
+    settings.setValue( "Right", radioButtonRightMiddle->isChecked() );
+    settings.setValue( "Bottom", radioButtonBottomMiddle->isChecked() );
+    settings.setValue( "Left", radioButtonLeftMiddle->isChecked() );
+  settings.endGroup();
+  webcamController->saveSettings();
 }
 
 
+void screencast::ShortcutWebcam()
+{
+  webcamCheckBox->click(); 
+}
+
 void screencast::ShortcutMagnifier()
 {
   MagnifierCheckBox->click();
@@ -1159,7 +1261,14 @@ void screencast::searchExternalPrograms()
     {
       recordApplikation = "avconv";
       qDebug() << "[vokoscreen] use avconv as ffmpeg-link";
-     }
+    }
+/*    
+    if ( fileInfo.baseName() == "ffmpeg" )
+    {
+      recordApplikation = "ffmpeg";
+      qDebug() << "[vokoscreen] use ffmpeg as ffmpeg-link";
+    }
+*/    
   }
   else
   {
@@ -1179,12 +1288,12 @@ void screencast::searchExternalPrograms()
   }
   
   if ( needProgram("pactl") )
-     qDebug() << "[vokoscreen]" << "Find pactl";
+     qDebug() << "[vokoscreen]" << "Find pactl Version:" << getPactlVersion();
   else
      qDebug() << "[vokoscreen]" << "Error: pactl is not found, this is an PulseAudio-utils tool. Please install pactl";
   
   if ( needProgram("mkvmerge") )
-     qDebug() << "[vokoscreen]" << "Find mkvmerge";
+     qDebug() << "[vokoscreen]" << "Find mkvmerge Version:" << getMkvmergeVersion();
   else
      qDebug() << "[vokoscreen]" << "Error: mkvmerge is not found, this is an mkvtoolnix tool. Please install mkvmerge";
   
@@ -1470,7 +1579,7 @@ void screencast::error( QProcess::ProcessError error )
     for ( int i = 0; i < stringList.count(); ++i )
       QFile::copy( workDirectory + QDir::separator() + stringList[ i ], workDirectory + QDir::separator() + "crashed" + QDir::separator() + stringList[ i ]);
     
-    QString crashedtext = "[vokoscreen] ffmpeg is crashed on ";
+    QString crashedtext = "[vokoscreen] " + recordApplikation + " is crashed on ";
     QDateTime dateTime = QDateTime::currentDateTime();
     QString time = dateTime.toString( "hh:mm" );
     QString day = dateTime.toString( "dddd" );
@@ -1556,11 +1665,7 @@ void screencast::Pause()
       QvkAlsaDevice *inBox = AlsaDeviceList.at( aa.toInt() );
       if ( inBox->isbusy() and AlsaRadioButton->isChecked() )
       {
-        QMessageBox msgBox;
-        QString message;
-        message.append( tr( "Device %1 is busy" ).arg( inBox->getAlsaHw() ) );
-	msgBox.setText( message );
-        msgBox.exec();
+        inBox->busyDialog( inBox->getAlsaHw(), inBox->getPurAlsaName() );
 	PauseButton->click();
         return;
       }
@@ -1590,12 +1695,8 @@ void screencast::Pause()
       QvkAlsaDevice *inBox = AlsaDeviceList.at( aa.toInt() );
       if ( inBox->isbusy() and AlsaRadioButton->isChecked() )
       {
-        QMessageBox msgBox;
-        QString message;
-        message.append( tr( "Device %1 is busy" ).arg( inBox->getAlsaHw() ) );
-        msgBox.setText( message );
-        msgBox.exec();
-	PauseButton->click();
+        inBox->busyDialog( inBox->getAlsaHw(), inBox->getPurAlsaName() );
+        PauseButton->click();
         return;
       }
       Countdown();
@@ -1637,6 +1738,34 @@ void screencast::play()
 }
 
 
+QString screencast::getPactlVersion()
+{
+  QProcess Process;
+  Process.start("pactl --version");
+  Process.waitForFinished();
+  QString pactlVersion = Process.readAllStandardOutput();
+  Process.close();
+
+  QStringList list = pactlVersion.split( "\n" );
+  list = list[ 0 ].split( " " );
+  return list[ 1 ];
+}
+
+
+QString screencast::getMkvmergeVersion()
+{
+  QProcess Process;
+  Process.start("mkvmerge --version");
+  Process.waitForFinished();
+  QString mkvmergeVersion = Process.readAllStandardOutput();
+  Process.close();
+
+  QStringList list = mkvmergeVersion.split( "\n" );
+  list = list[ 0 ].split( " " );
+  return list[ 1 ];
+}
+
+
 QString screencast::getAvconvVersion()
 {
   QProcess Process;
@@ -1884,7 +2013,7 @@ QString screencast::getPulseSample( int value )
  */
 QString screencast::mySample()
 {
-  QString ret = "48000";
+  QString ret = "41000";
   
   if ( PulseDeviceRadioButton->isChecked() )
   {
@@ -2271,12 +2400,7 @@ void screencast::preRecord()
     QvkAlsaDevice *inBox = AlsaDeviceList.at( aa.toInt() );
     if ( inBox->isbusy() )
     {
-      QMessageBox msgBox;
-      msgBox.setIcon( QMessageBox::Information );
-      QString message;
-      message.append( tr( "Device %1 is busy" ).arg( inBox->getAlsaHw() ) );
-      msgBox.setText( message );
-      msgBox.exec();
+      inBox->busyDialog( inBox->getAlsaHw(), inBox->getPurAlsaName() );
       return;
     }
     else
@@ -2393,8 +2517,8 @@ void screencast::record()
   if ( FullScreenRadioButton->isChecked() )
   {
     QDesktopWidget *desk = QApplication::desktop();
-    setRecordWidth( tr( "%1" ).arg( desk->screenGeometry().width() ) );
-    setRecordHeight( tr( "%1" ).arg( desk->screenGeometry().height() ) );
+    setRecordWidth( QString::number( desk->screenGeometry().width() ) );
+    setRecordHeight( QString::number( desk->screenGeometry().height() ) );
   }
 
   QString deltaX = "0";
@@ -2429,6 +2553,33 @@ void screencast::record()
       windowMoveTimer->start( 120 );
       firststartWininfo = true;
   }
+
+  if( FullScreenRadioButton->isChecked() )
+  {
+      int screen = ScreenComboBox->itemData( ScreenComboBox->currentIndex() ).toInt();
+      qDebug() << "[vokoscreen]" << "Report: recording fullscreen: " << screen;
+
+      int fullScreenWidth = 0;
+      int fullScreenHeight = 0;
+
+      QDesktopWidget *desk = QApplication::desktop();
+      for ( int i = 0; i < desk->screenCount(); i++ )
+      {
+          // skip if we are recording a specific screen and this isn't it.
+          if( screen != -1 && screen != i ) continue;
+          // set the offset if we are recording a specific screen.
+          if( screen != -1 )
+          {
+              deltaX = QString::number( desk->screenGeometry( i + 1 ).left() );
+              deltaY = QString::number( desk->screenGeometry( i + 1 ).top() );
+          }
+          fullScreenWidth += desk->screenGeometry( i + 1 ).width();
+          fullScreenHeight = std::max( fullScreenHeight, desk->screenGeometry( i + 1 ).height() );
+      }
+
+      setRecordWidth( QString::number( fullScreenWidth ) );
+      setRecordHeight( QString::number( fullScreenHeight) );
+  }  
   
   if ( AreaRadioButton->isChecked() )
   {
@@ -2437,8 +2588,6 @@ void screencast::record()
     deltaX  = QString().number( myregionselection->getXRecordArea() );
     deltaY  = QString().number( myregionselection->getYRecordArea() );
 
-    myregionselection->cleanRecordArea( true );
-    
     //Makes the rectangle unmovable and unresizeable (Is enabled yet again when process finished)
     myregionselection->lockFrame( true );
   }
@@ -2479,10 +2628,15 @@ void screencast::record()
   for ( int i = 0; i < stringList.size(); ++i )
      dir.remove( PathTempLocation().append(QDir::separator() ).append(stringList.at( i ) ) );
 
-  // frame rate
-  //QString frame = "-r " + QString().number( FrameSpinBox->value() );
-  QString framerate = "-framerate " + QString().number( FrameSpinBox->value() );
-  // Videocodec
+  // framerate
+  QString framerate;
+  if ( recordApplikation == "ffmpeg" )
+    framerate = "-framerate " + QString().number( FrameSpinBox->value() );
+  
+  if ( recordApplikation == "avconv" )
+    framerate = "-r " + QString().number( FrameSpinBox->value() );
+  
+
   QString myVcodec = VideocodecComboBox->currentText();
   if ( myVcodec == "libx264" )
   {
@@ -2496,10 +2650,7 @@ void screencast::record()
     if ( ( intRecordY % 2 ) == 1 )
       setRecordHeight( QString().number( --intRecordY ) );
     
-    myVcodec = "libx264 -preset veryfast"; // Standard
-    //myVcodec = "libx264 -preset medium";
-    //myVcodec = "libx264 -preset veryslow";
-    
+    myVcodec = "libx264 -preset veryfast";
   }  
 
   nameInMoviesLocation = NameInMoviesLocation();
@@ -2508,7 +2659,7 @@ void screencast::record()
   if ( ( getFfmpegVersion() < "01.01.00" ) and ( recordApplikation == "ffmpeg" ) )
     quality = " -sameq ";
   else
-    quality = " -qscale 1 ";
+    quality = " -q:v 1 ";
 
   clickedRecordButtonScreenSize();
 
@@ -2597,8 +2748,19 @@ void screencast::startRecord( QString RecordPathName )
     }
   }
   
+  // Webcam busybug abfangen
+  bool webcamRunning = false;
+  if ( webcamCheckBox->checkState() == Qt::Checked )
+  {
+    webcamCheckBox->click();
+    webcamRunning = true;
+  }
+  
   SystemCall->start( ffmpegString + RecordPathName );
 
+  if ( webcamRunning == true )
+   webcamCheckBox->click();  
+  
   // Recordtime Statusbar
   beginTime  = QDateTime::currentDateTime();
 
@@ -2607,9 +2769,6 @@ void screencast::startRecord( QString RecordPathName )
 
 void screencast::Stop()
 {
-  
-  myregionselection->cleanRecordArea( false );
-  
   shortcutStart->setEnabled( true );
   shortcutStop->setEnabled( false );
   
@@ -2631,19 +2790,9 @@ void screencast::Stop()
         mergeString.append( " + " ).append( PathTempLocation() ).append( QDir::separator() ).append( stringList.at( i ) );
 
     mergeString.append( " -o " ).append( PathMoviesLocation() + QDir::separator() + nameInMoviesLocation );
-/*
-    // Unter der Sprache Arabisch funktioniert mkvmerge nicht
-    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();// Test
-    env.insert("LANG", "ro_MD");// Test
-    SystemCall->setProcessEnvironment(env); //Test
-*/
     SystemCall->start( mergeString );
     SystemCall->waitForFinished();
-/*    
-    QString mkvAusgabe = SystemCall->readAllStandardOutput(); // Test
-    SystemCall->close(); / Test
-    qDebug() << "*****************Test*****" << mkvAusgabe; /Test
-*/    
+
     for ( int i = 0; i < stringList.size(); ++i )
       dir.remove( PathTempLocation().append( QDir::separator() ).append( stringList.at( i ) ) );
 
