@@ -1,5 +1,5 @@
 /* vokoscreen - A desktop recorder
- * Copyright (C) 2011-2013 Volker Kohaupt
+ * Copyright (C) 2011-2014 Volker Kohaupt
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,7 +12,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301 USA
  */
 
 #ifndef screencast_H 
@@ -32,9 +33,9 @@
 #include <QDate>
 #include <QStatusBar>
 #include <QDesktopWidget>
+#include <QDial>
 
 #include <QvkSettings.h>
-
 #include "regionselection.h"
 #include "QvkMagnifier.h"
 #include "QvkWebcamController.h"
@@ -46,14 +47,9 @@
 #include "QvkVersion.h"
 
 #include <QxtGlobalShortcut> 
-
 #include <QTest>
-
 #include <QDateTime>
 
-
-//#include <QEvent>
-
 class screencast : public QMainWindow
 { 
 Q_OBJECT
@@ -62,10 +58,9 @@ public:
     virtual ~screencast();
     QString getFfmpegVersion();
     QString getAvconvVersion();
+    QString getMkvmergeVersion();
+    QString getPactlVersion();
 
-
-//    QString ProgName;
-//    QString Version;
     QString email;
     QString homepage;
     QString ffmpegString;
@@ -159,7 +154,7 @@ private slots:
     void showMagnifier();
     void MagnifierDialog();
     
-
+    void ShortcutWebcam();
     void ShortcutPause();
     void ShortcutMagnifier();
     void uncheckMagnifier();
@@ -201,7 +196,14 @@ private:
     QPushButton *PauseButton;
     QPushButton *PlayButton;
     QPushButton *sendPushButton;
-    
+    QCheckBox *webcamCheckBox;
+    QCheckBox *mirrorCheckBox;
+    QDial *rotateDial;
+    QRadioButton *radioButtonTopMiddle;
+    QRadioButton *radioButtonRightMiddle;
+    QRadioButton *radioButtonBottomMiddle;
+    QRadioButton *radioButtonLeftMiddle;
+        
     QProcess *SystemCall;
     QRadioButton *AlsaRadioButton;
     QComboBox *AlsaHwComboBox;
@@ -210,19 +212,21 @@ private:
     QRadioButton * WindowRadioButton;
     QRadioButton *AreaRadioButton;
     QCheckBox *MagnifierCheckBox;
-    QvkWebcamController *webcamCheckBox;
     QSpinBox * CountdownSpinBox;
+    QComboBox * ScreenComboBox;
     
     QLabel *ChannelLabel;
     QComboBox *VideoplayerComboBox;
-    QFrame *TabWidgetAudioFrame;
     QLabel *recordTimeLabel;
     QLineEdit *SaveVideoPathLineEdit;
     QRadioButton *PulseDeviceRadioButton;
     
-    QFrame *TabWidgetMiscellaneousFrame;
+    QFrame *TabWidgetAudioFrame;
     QFrame *TabWidgetVideoOptionFrame;
+    QFrame *TabWidgetMiscellaneousFrame;
+    QFrame *TabWidgetWebcamFrame;
     QFrame *TabWidgetSocialFrame;
+    
     QSpinBox *FrameSpinBox;
     QComboBox *VideocodecComboBox;
     QComboBox *VideoContainerComboBox;
@@ -244,8 +248,9 @@ private:
     
     QvkMagnifier *magnifier;
     regionselection *myregionselection;
-    QvkWebcam *webcam;
+    QvkWebcamController *webcamController;
     
+    QxtGlobalShortcut *shortcutWebcam;
     QxtGlobalShortcut *shortcutMagnifier;
     QxtGlobalShortcut *shortcutPause;
     QxtGlobalShortcut *shortcutStart;
@@ -269,8 +274,6 @@ private:
     
     QString screenRecordWidth;
     QString screenRecordHeight;
-    //int leftFrameBorder;
-    //int topFrameBorder;
     
     QDateTime beginTime;
     
@@ -281,7 +284,12 @@ private:
 
  protected:
     void closeEvent( QCloseEvent * event );
-
+    
+    //bool event( QEvent *event );
+    
+    void changeEvent(QEvent *e);
+    
+    void styleChange( QStyle &asd );
 };
 
 
