@@ -1,7 +1,6 @@
 
 #include "QvkMail.h" 
 
-
 using namespace std;
 
 QvkMail::QvkMail()
@@ -12,8 +11,21 @@ QvkMail::QvkMail()
 
 QvkMail::QvkMail( QWidget *object )
 {
+  (void)object;
+  
+  newDialog = new QDialog;
+  newDialog->setModal( true );
+
+  myUiMailDialog.setupUi( newDialog );
+  newDialog->show();  
+  
+  connect( myUiMailDialog.sendPushButton, SIGNAL( clicked() ), this, SLOT( selection() ) );
+  connect( myUiMailDialog.cancelPushButton, SIGNAL( clicked() ), this, SLOT( closeDialog() ) ) ;
+
+  
+/*  
   dialog = new QDialog( object );
-  dialog->setFixedSize( 450, 200 );
+  dialog->setFixedSize( 470, 200 );
   
   QFont qfont = dialog->font();
   qfont.setPixelSize( 12 );
@@ -38,11 +50,19 @@ QvkMail::QvkMail( QWidget *object )
   mailSelectedRadioButton->setText( tr( "Mail one or more selected Video" ) );
   
   QPushButton * sendPushbutton = new QPushButton( dialog );
-  sendPushbutton->setGeometry( 200, 170, 80, 30 );
+  sendPushbutton->setGeometry( 290, 170, 80, 30 );
   sendPushbutton->setText( tr( "Send" ) );
   sendPushbutton->show();
   connect( sendPushbutton, SIGNAL( clicked() ), this, SLOT( selection() ) );
+  
+  QPushButton * closePushbutton = new QPushButton( dialog );
+  closePushbutton->setGeometry( 380, 170, 80, 30 );
+  closePushbutton->setText( tr( "Close" ) );
+  closePushbutton->show();
+  connect( closePushbutton, SIGNAL( clicked() ), this, SLOT( closeDialog() ) ) ;
+  
   dialog->exec();
+*/  
 }
 
 
@@ -51,12 +71,18 @@ QvkMail::~QvkMail()
 }
 
 
+void QvkMail::closeDialog()
+{
+  newDialog->close();
+}
+
+
 void QvkMail::selection()
 {
-  if ( mailRadioButton->isChecked() )
+  if ( myUiMailDialog.mailRadioButton->isChecked() )
     startMailClientWithLastFile( lastMovie() );
 
-  if ( mailSelectedRadioButton->isChecked() )
+  if ( myUiMailDialog.mailSelectedRadioButton->isChecked() )
     startMailClientWithSelectedFiles( selectedMail() );
 }
 
@@ -78,7 +104,7 @@ void QvkMail::startMailClientWithLastFile( QString file )
     Process.close();
   }
 
-  dialog->close();
+  newDialog->close();
 }
 
 
@@ -105,7 +131,7 @@ void QvkMail::startMailClientWithSelectedFiles( QStringList fileList )
     Process.close();
   }
   
-  dialog->close();
+  newDialog->close();
 }
 
 
@@ -127,7 +153,7 @@ QStringList QvkMail::selectedMail()
 
   QString a = QDesktopServices::storageLocation( QDesktopServices::MoviesLocation );
   
-  QStringList files = QFileDialog::getOpenFileNames( dialog,
+  QStringList files = QFileDialog::getOpenFileNames( newDialog,
                                                      tr( "Select one or more files" ),
                                                      QDesktopServices::storageLocation( QDesktopServices::MoviesLocation ) , 
                                                      "*.*" );
