@@ -54,6 +54,13 @@ public:
   int getAreaWidth();
   int getAreaHeight();
   
+  // webcam
+  int getWebcamX();
+  int getWebcamY();
+  int getWebcamHeight();
+  int getWebcamWidth();
+  bool getWebcamMirrored();
+  bool getWebcamBorder();
   
 public slots:
 
@@ -98,7 +105,14 @@ private:
   int AreaY;
   int AreaWidth;
   int AreaHeight;
-  
+
+  // webcam
+  int webcamX;
+  int webcamY;
+  int webcamHeight;
+  int webcamWidth;
+  bool webcamMirrored;
+  bool webcamBorder;
 };
 
 #endif
